=======================
Welcome to pypercolate!
=======================

.. only:: not latex

   .. include:: about-include.rst

.. toctree::
   :maxdepth: 2

   About <about>
   Setup <setup>
   Tutorial <tutorial-bond-square-lattice>
   Quickstart HPC <quickstart-hpc>
   User Guide <user>
   Developer Guide <developer>
   Reference <reference/percolate>
   zreferences
